@@ -2,4 +2,6 @@ from .proto_utils import ProtoTemplate, ProtoDataset
 from .data_utils import SparkDataset
 from .protos.mas import annotation_pb2 as annotation_proto
 from .protos.mas import image_data_pb2 as image_proto
-from .aws_utils import FireSparkAWS as S3
\ No newline at end of file
+from .aws_utils import FireSparkAWS as S3
+from .torch_utils import TorchLoaderBase as torch_loader
+from .numpy_utils import NumpyLoaderBase as np_loader
\ No newline at end of file
